@@ -1,7 +1,7 @@
 package App::wordlist;
 
-our $DATE = '2016-01-14'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2016-01-15'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -110,7 +110,7 @@ $SPEC{wordlist} = {
             'x.doc.show_result' => 0,
         },
         {
-            argv => [qw/-w KBBI foo/],
+            argv => [qw/-w ID::KBBI foo/],
             summary => 'Select a specific wordlist (multiple -w allowed)',
             test => 0,
             'x.doc.show_result' => 0,
@@ -121,6 +121,18 @@ $SPEC{wordlist} = {
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            argv => [qw/-l/],
+            summary => 'List installed wordlist modules',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            argv => [qw/-L/],
+            summary => 'List wordlist modules available on CPAN',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
     ],
     'cmdline.default_format' => 'text-simple',
 };
@@ -265,7 +277,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.16 of App::wordlist (from Perl distribution App-wordlist), released on 2016-01-14.
+This document describes version 0.17 of App::wordlist (from Perl distribution App-wordlist), released on 2016-01-15.
 
 =head1 SYNOPSIS
 
@@ -303,12 +315,20 @@ Examples:
 
 =item * Select a specific wordlist (multiple -w allowed):
 
- wordlist( arg => ["foo"], wordlist => ["KBBI"]);
+ wordlist( arg => ["foo"], wordlist => ["ID::KBBI"]);
 
 =item * Filter by regex:
 
  wordlist( arg => ["/fof[aeiou]/"]);
 
+=item * List installed wordlist modules:
+
+ wordlist( action => "list_installed");
+
+=item * List wordlist modules available on CPAN:
+
+ wordlist( action => "list_cpan");
+
 =back
 
 This function is not exportable.
